@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.044';
+our $VERSION = '0.045';
 
 use Dist::Zilla::App -command;
 
@@ -59,7 +59,7 @@ sub stale_modules
 
     return if not @modules;
 
-    my ($stale_modules, undef) = $plugins[0]->stale_modules(uniq(@modules));
+    my ($stale_modules, undef) = $plugins[0]->stale_modules(_uniq(@modules));
     return @$stale_modules;
 }
 
@@ -105,7 +105,7 @@ sub execute
         push @authordeps, $self->_missing_authordeps;
 
         $self->app->chrome->logger->unmute;
-        $self->log(join("\n", uniq(sort @authordeps)));
+        $self->log(join("\n", sort(_uniq(@authordeps))));
 
         if (@authordeps)
         {
@@ -147,7 +147,7 @@ sub _missing_authordeps
 }
 
 # until List::Util::uniq exists...
-sub uniq { require List::UtilsBy; unshift @_, sub { $_ }; goto &List::UtilsBy::uniq_by }
+sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
 
 1;
 
@@ -163,7 +163,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
@@ -190,7 +190,10 @@ Checks all plugins and prerequisites (as well as any additional modules listed
 in a local L<[PromptIfStale]|Dist::Zilla::Plugin::PromptIfStale>
 configuration, if there is one).
 
-=for Pod::Coverage stale_modules uniq
+I have a shell alias: C<alias unstale="dzil stale --all | cpanm"> which I use
+quite regularly! You should do this too.
+
+=for Pod::Coverage stale_modules
 
 =head1 SUPPORT
 
