@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.043-2-gf577e21
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.044-9-gd2196aa
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.044';
+our $VERSION = '0.045';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -14,7 +14,6 @@ with 'Dist::Zilla::Role::BeforeBuild',
 
 use Moose::Util::TypeConstraints 'enum';
 use List::Util 1.33 qw(none any);
-use List::UtilsBy ();
 use version;
 use Moose::Util 'find_meta';
 use Path::Tiny;
@@ -26,7 +25,7 @@ use Module::Path 0.18 'module_path';
 use Module::Metadata 1.000023;
 use Module::CoreList 5.20150214;
 use Encode ();
-use namespace::autoclean;
+use namespace::autoclean -also => ['_uniq'];
 
 sub mvp_multivalue_args { qw(modules skip) }
 sub mvp_aliases { {
@@ -95,7 +94,7 @@ around dump_config => sub
 };
 
 # until List::Util::uniq exists...
-sub uniq { unshift @_, sub { $_ }; goto &List::UtilsBy::uniq_by }
+sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
 
 sub before_build
 {
@@ -103,12 +102,13 @@ sub before_build
 
     if ($self->phase eq 'build')
     {
-        my @modules = uniq
+        my @modules = (
             $self->_modules_extra,
             ( $self->check_authordeps ? $self->_authordeps : () ),
-            ( $self->check_all_plugins ? $self->_modules_plugin : () );
+            ( $self->check_all_plugins ? $self->_modules_plugin : () ),
+        );
 
-        $self->_check_modules(@modules) if @modules;
+        $self->_check_modules(sort(_uniq(@modules))) if @modules;
     }
 }
 
@@ -119,7 +119,7 @@ sub after_build
     if ($self->phase eq 'build' and $self->check_all_prereqs)
     {
         my @modules = $self->_modules_prereq;
-        $self->_check_modules(uniq @modules) if @modules;
+        $self->_check_modules(sort(_uniq(@modules))) if @modules;
     }
 }
 
@@ -135,7 +135,7 @@ sub before_release
         );
         push @modules, $self->_modules_prereq if $self->check_all_prereqs;
 
-        $self->_check_modules(uniq @modules) if @modules;
+        $self->_check_modules(sort(_uniq(@modules))) if @modules;
     }
 }
 
@@ -152,8 +152,11 @@ sub stale_modules
 {
     my ($self, @modules) = @_;
 
+    my $cwd = getcwd();
+    my $cwd_volume = path($cwd)->volume;
+
     my (@stale_modules, @errors);
-    foreach my $module (uniq sort @modules)
+    foreach my $module (sort(_uniq(@modules)))
     {
         $already_checked{$module}++ if $module eq 'perl';
         next if $already_checked{$module};
@@ -178,17 +181,18 @@ sub stale_modules
         $module_to_filename{$module} = $path;
 
         # ignore modules in the dist currently being built
-        my $relative_path = path($path)->relative(getcwd);
-        $already_checked{$module}++,
-            $self->log_debug([ '%s provided locally (at %s); skipping version check',
-                $module, $relative_path->stringify ])
-            unless $relative_path =~ m/^\.\./;
-    }
+        if (path($path)->volume eq $cwd_volume)
+        {
+            my $relative_path = path($path)->relative($cwd);
+            if ($relative_path !~ m/^\.\./)
+            {
+                $already_checked{$module}++;
+                $self->log_debug([ '%s provided locally (at %s); skipping version check',
+                    $module, $relative_path->stringify ]);
+                next;
+            }
+        }
 
-    @modules = grep { !$already_checked{$_} } @modules;
-
-    foreach my $module (@modules)
-    {
         my $indexed_version = $self->_indexed_version($module, !!(@modules > 5));
         my $local_version = Module::Metadata->new_from_file($module_to_filename{$module})->version;
 
@@ -278,9 +282,10 @@ has _authordeps => (
         my @skip = $self->skip;
         [
             grep { my $module = $_; none { $module eq $_ } @skip }
-            uniq
-            map { (%$_)[0] }
-                @{ Dist::Zilla::Util::AuthorDeps::extract_author_deps('.') }
+            _uniq(
+                map { (%$_)[0] }
+                    @{ Dist::Zilla::Util::AuthorDeps::extract_author_deps('.') }
+            )
         ];
     },
 );
@@ -295,8 +300,9 @@ has _modules_plugin => (
         my @skip = $self->skip;
         [
             grep { my $module = $_; none { $module eq $_ } @skip }
-            uniq
-            map { find_meta($_)->name } @{ $self->zilla->plugins }
+            _uniq(
+                map { find_meta($_)->name } @{ $self->zilla->plugins }
+            )
         ];
     },
 );
@@ -452,7 +458,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
@@ -532,7 +538,7 @@ When provided, uses this base URL to fetch F<02packages.details.txt.gz>
 instead of the default C<http://www.cpan.org>.  Use this when your
 distribution uses prerequisites found only in your darkpan-like server.
 
-=for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release uniq
+=for Pod::Coverage mvp_multivalue_args mvp_aliases before_build after_build before_release
 
 =head1 METHODS
 
@@ -582,6 +588,12 @@ L<Dist::Zilla::Plugin::Prereqs::MatchInstalled>, L<Dist::Zilla::Plugin::Prereqs:
 
 Karen Etheridge <ether@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords David Golden
+
+David Golden <dagolden@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Karen Etheridge.
@@ -589,10 +601,4 @@ This software is copyright (c) 2013 by Karen Etheridge.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTOR
-
-=for stopwords David Golden
-
-David Golden <dagolden@cpan.org>
-
 =cut
